@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '2.13';
+our $VERSION = '2.18';
 
 use Cwd 3;
 use Try::Tiny;
@@ -89,7 +89,16 @@ sub _FindMatchingZoneinfoFile {
     shift;
     my $file_to_match = shift;
 
-    return unless -d $ZoneinfoDir;
+    # For some reason, under at least macOS 10.13 High Sierra,
+    # /usr/share/zoneinfo is a link to a link to a directory. And no, I didn't
+    # stutter. This is fine, and it passes the -d below. But File::Find does
+    # not understand a link to be a directory, so rather than incur the
+    # overhead of telling File::Find::find() to follow symbolic links, we just
+    # resolve it here.
+    my $zone_info_dir = $ZoneinfoDir;
+    $zone_info_dir = readlink $zone_info_dir while -l $zone_info_dir;
+
+    return unless -d $zone_info_dir;
 
     require File::Basename;
     require File::Compare;
@@ -117,7 +126,7 @@ sub _FindMatchingZoneinfoFile {
                         # false positive
                         && File::Basename::basename($_) ne 'posixrules'
                         && File::Compare::compare( $_, $file_to_match ) == 0
-                        ) {
+                    ) {
                         $real_name = $_;
 
                         # File::Find has no mechanism for bailing in the
@@ -127,7 +136,7 @@ sub _FindMatchingZoneinfoFile {
                 },
                 no_chdir => 1,
             },
-            $ZoneinfoDir,
+            $zone_info_dir,
         );
     }
     catch {
@@ -274,7 +283,7 @@ DateTime::TimeZone::Local::Unix - Determine the local system's time zone on Unix
 
 =head1 VERSION
 
-version 2.13
+version 2.18
 
 =head1 SYNOPSIS
 
@@ -350,7 +359,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Dave Rolsky.
+This software is copyright (c) 2018 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
