@@ -1,29 +1,19 @@
 package DateTime::TimeZone::OlsonDB::Rule;
-$DateTime::TimeZone::OlsonDB::Rule::VERSION = '1.93';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '2.18';
 
-use DateTime;
 use DateTime::Duration;
 use DateTime::TimeZone::OlsonDB;
 
-use Params::Validate qw( validate SCALAR );
-
 sub new {
     my $class = shift;
-    my %p     = validate(
-        @_, {
-            name   => { type => SCALAR },
-            from   => { type => SCALAR },
-            to     => { type => SCALAR },
-            type   => { type => SCALAR, default => undef },
-            in     => { type => SCALAR },
-            on     => { type => SCALAR },
-            at     => { type => SCALAR },
-            save   => { type => SCALAR },
-            letter => { type => SCALAR, default => '' },
-        },
-    );
+    my %p     = @_;
+
+    $p{letter} ||= q{};
 
     my $save = $p{save};
 
@@ -70,8 +60,10 @@ sub utc_start_datetime_for_year {
     # should be the offset of the _previous_ rule
     my $offset_from_std = shift;
 
-    my $day = DateTime::TimeZone::OlsonDB::parse_day_spec( $self->on,
-        $self->month, $year );
+    my $day = DateTime::TimeZone::OlsonDB::parse_day_spec(
+        $self->on,
+        $self->month, $year
+    );
 
     my $utc = DateTime::TimeZone::OlsonDB::utc_datetime_for_time_spec(
         spec            => $self->at,
