@@ -1,7 +1,10 @@
 package DateTime::TimeZone::UTC;
-$DateTime::TimeZone::UTC::VERSION = '1.95';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '2.18';
 
 use parent 'Class::Singleton', 'DateTime::TimeZone';
 
@@ -9,11 +12,13 @@ sub new {
     return shift->instance;
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _new_instance {
     my $class = shift;
 
     return bless { name => 'UTC' }, $class;
 }
+## use critic
 
 sub is_dst_for_datetime {0}
 
@@ -34,13 +39,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::TimeZone::UTC - The UTC time zone
 
 =head1 VERSION
 
-version 1.95
+version 2.18
 
 =head1 SYNOPSIS
 
@@ -59,15 +66,28 @@ The offset for this object will always be zero.
 This class has the same methods as a real time zone object, but the
 C<category()> method returns undef and C<is_utc()> returns true.
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime-TimeZone/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for DateTime-TimeZone can be found at L<https://github.com/houseabsolute/DateTime-TimeZone>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Dave Rolsky.
+This software is copyright (c) 2018 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
